@@ -117,9 +117,13 @@ class Connection:
                         secmec = int.from_bytes(v[:2], byteorder='big')
                     elif sub_cp == cp.SECTKN:
                         sectkn = v
+            elif code_point == cp.RDBNFNRM:
+                from drda import DatabaseError
+                raise DatabaseError(0, 0, "database not found")
+
         return secmec, sectkn
 
-    def __init__(self, host, database, port, user, password, use_ssl, db_type, timeout):
+    def __init__(self, host, database, port, user, password, use_ssl, ssl_ca_certs, db_type, timeout):
         self.host = host
         self.database = (database + ' ' * 18)[:18]
         self.port = port
@@ -161,7 +165,7 @@ class Connection:
         if timeout is not None:
             self.sock.settimeout(timeout)
         if use_ssl:
-            self.sock = ssl.wrap_socket(self.sock)
+            self.sock = ssl.wrap_socket(self.sock, ca_certs=ssl_ca_certs)
         self.sock.connect((self.host, self.port))
 
         cur_id = 1
@@ -226,7 +230,7 @@ class Connection:
 
         self._parse_response()
 
-        self._set_valiables()
+        self._set_variables()
 
     def __enter__(self):
         return self
@@ -234,7 +238,7 @@ class Connection:
     def __exit__(self, exc, value, traceback):
         self.close()
 
-    def _set_valiables(self):
+    def _set_variables(self):
         lc_type = locale.getlocale()[0]
         if lc_type is None:
             lc_type = "en_US"
